@@ -5,7 +5,7 @@ use warnings;
 package Sub::MultiMethod;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '1.002';
+our $VERSION   = '1.003';
 
 use B ();
 use Eval::TypeTiny qw( set_subname );
@@ -1273,6 +1273,15 @@ exported functions can be renamed, etc.
 
   use Sub::MultiMethod multimethod => { -as => 'mm' };
 
+You can import everything using C<< -all >>:
+
+  use Sub::MultiMethod -all;
+
+If your Perl version is recent enough, you can import everything as lexical
+keywords:
+
+  use Sub::MultiMethod -lexical, -all;
+
 You may also set various defaults in the import:
 
   use Sub::MultiMethod multimethod => {
